==> aws-cdk-lib-2.0.0-rc.6-sources.jar: software/amazon/awscdk/services/config/CfnStoredQueryProps.java <==
package software.amazon.awscdk.services.config;

/**
 * Properties for defining a `AWS::Config::StoredQuery`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.29.0 (build 41df200)", date = "2021-06-02T09:55:16.804Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_config.CfnStoredQueryProps")
@software.amazon.jsii.Jsii.Proxy(CfnStoredQueryProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnStoredQueryProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::Config::StoredQuery.QueryExpression`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getQueryExpression();

    /**
     * `AWS::Config::StoredQuery.QueryName`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getQueryName();

    /**
     * `AWS::Config::StoredQuery.QueryDescription`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getQueryDescription() {
        return null;
    }

    /**
     * `AWS::Config::StoredQuery.Tags`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.CfnTag> getTags() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnStoredQueryProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnStoredQueryProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnStoredQueryProps> {
        private java.lang.String queryExpression;
        private java.lang.String queryName;
        private java.lang.String queryDescription;
        private java.util.List<software.amazon.awscdk.CfnTag> tags;

        /**
         * Sets the value of {@link CfnStoredQueryProps#getQueryExpression}
         * @param queryExpression `AWS::Config::StoredQuery.QueryExpression`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder queryExpression(java.lang.String queryExpression) {
            this.queryExpression = queryExpression;
            return this;
        }

        /**
         * Sets the value of {@link CfnStoredQueryProps#getQueryName}
         * @param queryName `AWS::Config::StoredQuery.QueryName`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder queryName(java.lang.String queryName) {
            this.queryName = queryName;
            return this;
        }

        /**
         * Sets the value of {@link CfnStoredQueryProps#getQueryDescription}
         * @param queryDescription `AWS::Config::StoredQuery.QueryDescription`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder queryDescription(java.lang.String queryDescription) {
            this.queryDescription = queryDescription;
            return this;
        }

        /**
         * Sets the value of {@link CfnStoredQueryProps#getTags}
         * @param tags `AWS::Config::StoredQuery.Tags`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder tags(java.util.List<? extends software.amazon.awscdk.CfnTag> tags) {
            this.tags = (java.util.List<software.amazon.awscdk.CfnTag>)tags;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnStoredQueryProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnStoredQueryProps build() {
            return new Jsii$Proxy(queryExpression, queryName, queryDescription, tags);
        }
    }

    /**
     * An implementation for {@link CfnStoredQueryProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnStoredQueryProps {
        private final java.lang.String queryExpression;
        private final java.lang.String queryName;
        private final java.lang.String queryDescription;
        private final java.util.List<software.amazon.awscdk.CfnTag> tags;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.queryExpression = software.amazon.jsii.Kernel.get(this, "queryExpression", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.queryName = software.amazon.jsii.Kernel.get(this, "queryName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.queryDescription = software.amazon.jsii.Kernel.get(this, "queryDescription", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.tags = software.amazon.jsii.Kernel.get(this, "tags", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.CfnTag.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final java.lang.String queryExpression, final java.lang.String queryName, final java.lang.String queryDescription, final java.util.List<? extends software.amazon.awscdk.CfnTag> tags) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.queryExpression = java.util.Objects.requireNonNull(queryExpression, "queryExpression is required");
            this.queryName = java.util.Objects.requireNonNull(queryName, "queryName is required");
            this.queryDescription = queryDescription;
            this.tags = (java.util.List<software.amazon.awscdk.CfnTag>)tags;
        }

        @Override
        public final java.lang.String getQueryExpression() {
            return this.queryExpression;
        }

        @Override
        public final java.lang.String getQueryName() {
            return this.queryName;
        }

        @Override
        public final java.lang.String getQueryDescription() {
            return this.queryDescription;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.CfnTag> getTags() {
            return this.tags;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("queryExpression", om.valueToTree(this.getQueryExpression()));
            data.set("queryName", om.valueToTree(this.getQueryName()));
            if (this.getQueryDescription() != null) {
                data.set("queryDescription", om.valueToTree(this.getQueryDescription()));
            }
            if (this.getTags() != null) {
                data.set("tags", om.valueToTree(this.getTags()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_config.CfnStoredQueryProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnStoredQueryProps.Jsii$Proxy that = (CfnStoredQueryProps.Jsii$Proxy) o;

            if (!queryExpression.equals(that.queryExpression)) return false;
            if (!queryName.equals(that.queryName)) return false;
            if (this.queryDescription != null ? !this.queryDescription.equals(that.queryDescription) : that.queryDescription != null) return false;
            return this.tags != null ? this.tags.equals(that.tags) : that.tags == null;
        }

        @Override
        public final int hashCode() {
            int result = this.queryExpression.hashCode();
            result = 31 * result + (this.queryName.hashCode());
            result = 31 * result + (this.queryDescription != null ? this.queryDescription.hashCode() : 0);
            result = 31 * result + (this.tags != null ? this.tags.hashCode() : 0);
            return result;
        }
    }
}

==> aws-cdk-lib-2.10.0-sources.jar: software/amazon/awscdk/services/config/CfnStoredQueryProps.java <==
package software.amazon.awscdk.services.config;

/**
 * Properties for defining a `CfnStoredQuery`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.config.*;
 * CfnStoredQueryProps cfnStoredQueryProps = CfnStoredQueryProps.builder()
 *         .queryExpression("queryExpression")
 *         .queryName("queryName")
 *         // the properties below are optional
 *         .queryDescription("queryDescription")
 *         .tags(List.of(CfnTag.builder()
 *                 .key("key")
 *                 .value("value")
 *                 .build()))
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.52.1 (build 5ccc8f6)", date = "2022-01-29T04:34:08.633Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_config.CfnStoredQueryProps")
@software.amazon.jsii.Jsii.Proxy(CfnStoredQueryProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnStoredQueryProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The expression of the query.
     * <p>
     * For example, <code>SELECT resourceId, resourceType, supplementaryConfiguration.BucketVersioningConfiguration.status WHERE resourceType = 'AWS::S3::Bucket' AND supplementaryConfiguration.BucketVersioningConfiguration.status = 'Off'.</code>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getQueryExpression();

    /**
     * The name of the query.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getQueryName();

    /**
     * A unique description for the query.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getQueryDescription() {
        return null;
    }

    /**
     * An array of key-value pairs to apply to this resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.CfnTag> getTags() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnStoredQueryProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnStoredQueryProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnStoredQueryProps> {
        java.lang.String queryExpression;
        java.lang.String queryName;
        java.lang.String queryDescription;
        java.util.List<software.amazon.awscdk.CfnTag> tags;

        /**
         * Sets the value of {@link CfnStoredQueryProps#getQueryExpression}
         * @param queryExpression The expression of the query. This parameter is required.
         *                        For example, <code>SELECT resourceId, resourceType, supplementaryConfiguration.BucketVersioningConfiguration.status WHERE resourceType = 'AWS::S3::Bucket' AND supplementaryConfiguration.BucketVersioningConfiguration.status = 'Off'.</code>
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder queryExpression(java.lang.String queryExpression) {
            this.queryExpression = queryExpression;
            return this;
        }

        /**
         * Sets the value of {@link CfnStoredQueryProps#getQueryName}
         * @param queryName The name of the query. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder queryName(java.lang.String queryName) {
            this.queryName = queryName;
            return this;
        }

        /**
         * Sets the value of {@link CfnStoredQueryProps#getQueryDescription}
         * @param queryDescription A unique description for the query.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder queryDescription(java.lang.String queryDescription) {
            this.queryDescription = queryDescription;
            return this;
        }

        /**
         * Sets the value of {@link CfnStoredQueryProps#getTags}
         * @param tags An array of key-value pairs to apply to this resource.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder tags(java.util.List<? extends software.amazon.awscdk.CfnTag> tags) {
            this.tags = (java.util.List<software.amazon.awscdk.CfnTag>)tags;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnStoredQueryProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnStoredQueryProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnStoredQueryProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnStoredQueryProps {
        private final java.lang.String queryExpression;
        private final java.lang.String queryName;
        private final java.lang.String queryDescription;
        private final java.util.List<software.amazon.awscdk.CfnTag> tags;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.queryExpression = software.amazon.jsii.Kernel.get(this, "queryExpression", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.queryName = software.amazon.jsii.Kernel.get(this, "queryName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.queryDescription = software.amazon.jsii.Kernel.get(this, "queryDescription", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.tags = software.amazon.jsii.Kernel.get(this, "tags", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.CfnTag.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.queryExpression = java.util.Objects.requireNonNull(builder.queryExpression, "queryExpression is required");
            this.queryName = java.util.Objects.requireNonNull(builder.queryName, "queryName is required");
            this.queryDescription = builder.queryDescription;
            this.tags = (java.util.List<software.amazon.awscdk.CfnTag>)builder.tags;
        }

        @Override
        public final java.lang.String getQueryExpression() {
            return this.queryExpression;
        }

        @Override
        public final java.lang.String getQueryName() {
            return this.queryName;
        }

        @Override
        public final java.lang.String getQueryDescription() {
            return this.queryDescription;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.CfnTag> getTags() {
            return this.tags;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("queryExpression", om.valueToTree(this.getQueryExpression()));
            data.set("queryName", om.valueToTree(this.getQueryName()));
            if (this.getQueryDescription() != null) {
                data.set("queryDescription", om.valueToTree(this.getQueryDescription()));
            }
            if (this.getTags() != null) {
                data.set("tags", om.valueToTree(this.getTags()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_config.CfnStoredQueryProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnStoredQueryProps.Jsii$Proxy that = (CfnStoredQueryProps.Jsii$Proxy) o;

            if (!queryExpression.equals(that.queryExpression)) return false;
            if (!queryName.equals(that.queryName)) return false;
            if (this.queryDescription != null ? !this.queryDescription.equals(that.queryDescription) : that.queryDescription != null) return false;
            return this.tags != null ? this.tags.equals(that.tags) : that.tags == null;
        }

        @Override
        public final int hashCode() {
            int result = this.queryExpression.hashCode();
            result = 31 * result + (this.queryName.hashCode());
            result = 31 * result + (this.queryDescription != null ? this.queryDescription.hashCode() : 0);
            result = 31 * result + (this.tags != null ? this.tags.hashCode() : 0);
            return result;
        }
    }
}
